mathUtils
================

.. automodule:: biskit.mathUtils
   :members:
   :exclude-members: Test

   
   
   .. rubric:: Functions Overview

   .. autosummary::
      :nosignatures:
   
      SD
      aboveDiagonal
      accumulate
      area
      arrayEqual
      cartesian2D
      cartesianToPolar
      cbrt
      cubic
      difference
      eulerRotation
      intersection
      linfit
      listToMatrix
      matrixToList
      nonredundant
      outliers
      packBinaryMatrix
      pairwiseDistances
      polar2D
      polarToCartesian
      projectOnSphere
      quadratic
      random2DArray
      randomMask
      randomRange
      randomRotation
      removeFromList
      rotateAxis
      runningAverage
      slidingAverage
      union
      unpackBinaryMatrix
      variance
      wMean
      wSD
      wVar
   
   

   
   
   .. rubric:: Classes Overview

   .. autosummary::
      :nosignatures:
   
      
   
   

   
   
   .. rubric:: Exceptions Defined in this Module

   .. autosummary::
      :nosignatures:
   
      MathUtilError
   
   

   .. raw:: html
               
      <hr>
      <h2>mathUtils Module Details</h2>